Module bincode::enc::write [−][src]
This module contains writer-based structs and traits.
Because std::io::Write is only limited to std and not core, we provide our own Writer.
Structs
A helper struct that implements Writer for a &[u8] slice.