Enum bincode::error::EncodeError[][src]

#[non_exhaustive]
pub enum EncodeError {
    UnexpectedEnd,
    RefCellAlreadyBorrowed {
        inner: BorrowError,
        type_name: &'static str,
    },
    Other(&'static str),
    OtherString(String),
    InvalidPathCharacters,
    Io {
        error: Error,
        index: usize,
    },
    LockFailed {
        type_name: &'static str,
    },
    InvalidSystemTime {
        inner: SystemTimeError,
        time: SystemTime,
    },
    SequenceMustHaveLength,
}
Errors that can be encountered by encoding a type

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedEnd

The writer ran out of storage.

RefCellAlreadyBorrowed

The RefCell is already borrowed

Fields of RefCellAlreadyBorrowed

inner: BorrowError

The inner borrow error

type_name: &'static str

the type name of the RefCell being encoded that is currently borrowed.

Other(&'static str)

An uncommon error occured, see the inner text for more information

Tuple Fields of Other

0: &'static str
OtherString(String)

An uncommon error occured, see the inner text for more information

Tuple Fields of OtherString

0: String
InvalidPathCharacters

A std::path::Path was being encoded but did not contain a valid &str representation

Io

The targetted writer encountered an std::io::Error

Fields of Io

error: Error

The encountered error

index: usize

The amount of bytes that were written before the error occured

LockFailed

The encoder tried to encode a Mutex or RwLock, but the locking failed

Fields of LockFailed

type_name: &'static str

The type name of the mutex for debugging purposes

InvalidSystemTime

The encoder tried to encode a SystemTime, but it was before SystemTime::UNIX_EPOCH

Fields of InvalidSystemTime

inner: SystemTimeError

The error that was thrown by the SystemTime

time: SystemTime

The SystemTime that caused the error

SequenceMustHaveLength

Serde provided bincode with a sequence without a length, which is not supported in bincode