Struct bincode::de::DecoderImpl [−][src]
pub struct DecoderImpl<R, C: Config> { /* fields omitted */ }Expand description
A Decoder that reads bytes from a given reader R.
This struct should rarely be used.
In most cases, prefer any of the decode functions.
The ByteOrder that is chosen will impact the endianness that is used to read integers out of the reader.
use bincode::de::{DecoderImpl, Decode};
use bincode::config;
let mut decoder = DecoderImpl::new(some_reader, config::Configuration::standard());
// this u32 can be any Decode
let value = u32::decode(&mut decoder).unwrap();Implementations
Construct a new Decoder