Trait bincode::enc::Encode [−][src]
pub trait Encode {
fn encode<E: Encoder>(&self, encoder: E) -> Result<(), EncodeError>;
}Expand description
Any source that can be encoded. This trait should be implemented for all types that you want to be able to use with any of the encode_with methods.
This trait will be automatically implemented if you enable the derive feature and add #[derive(bincode::Encode)] to your trait.