Struct bincode::StrBox
[−]
[src]
pub struct StrBox<'a> {
// some fields omitted
}Like a RefBox, but encoding from a str and decoedes to a String.
Methods
impl<'a> StrBox<'a>[src]
impl StrBox<'static>[src]
fn take(self) -> String
Takes the value out of this refbox.
Fails if this refbox was not created out of a deserialization.
Unless you are doing some really weird things with static references, this function will never fail.
fn try_take(self) -> Result<String, StrBox<'static>>
Tries to take the value out of this refbox.